This package is for helping those who are writing the exam for computer science from Arbor International School, Hyderabad. Used by only one person. (Anonymous)

Official repository - (Test) https://test.pypi.org/project/Littledog-LittleDog5727/0.0.2/ (Source code & Build)